# hdns

[![License](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![PyPI version](https://badge.fury.io/py/your-package-name.svg)](https://badge.fury.io/py/your-package-name)

## Overview

This library is intended for people that do not have an static IP from their ISP but want to keep updated their A records at Hetzner DNS service

## Installation

Dependencies:
	requests
	json
	sys

```bash
pip install hdns
